@@ -1,9 +1,7 @@
 #include <glib.h>
 #include <gio/gio.h>
-#include <gcrypt.h>
 #include <jansson.h>
 #include <time.h>
-#include "file-size.h"
 #include "gquarks.h"
 #include "parse-uri.h"
 
@@ -13,28 +11,7 @@ get_freeotpplus_data (const gchar  *path,
                       gint32        max_file_size,
                       GError      **err)
 {
-    GSList *otps = NULL;
-    goffset fs = get_file_size (path);
-    if (fs < 10) {
-        g_set_error (err, file_too_big_gquark (), GENERIC_ERRCODE, "Couldn't get the file size (file doesn't exit or wrong file selected.");
-        return NULL;
-    }
-    if (fs > max_file_size) {
-        g_set_error (err, file_too_big_gquark (), FILE_TOO_BIG, FILE_SIZE_SECMEM_MSG);
-        return NULL;
-    }
-    gchar *sec_buf = gcry_calloc_secure (fs, 1);
-    if (!g_file_get_contents (path, &sec_buf, NULL, err)) {
-        g_printerr("Couldn't read into memory the freeotp txt file.\n");
-        gcry_free (sec_buf);
-        return NULL;
-    }
-
-    set_otps_from_uris (sec_buf, &otps);
-
-    gcry_free (sec_buf);
-
-    return otps;
+    return get_otpauth_data (path, max_file_size, err);
 }
 
 
